@@ -6,7 +6,7 @@ DOCSIS::ConfigFile - Decodes and encodes DOCSIS config-files
 
 =head1 VERSION
 
-0.62
+0.63
 
 =head1 SYNOPSIS
 
@@ -87,6 +87,7 @@ use autodie;
 use Carp qw/ carp confess /;
 use Digest::MD5;
 use Digest::HMAC_MD5;
+use Digest::SHA1 qw(sha1_hex);
 use DOCSIS::ConfigFile::Syminfo;
 use DOCSIS::ConfigFile::Decode;
 use DOCSIS::ConfigFile::Encode;
@@ -95,7 +96,7 @@ use constant Syminfo => "DOCSIS::ConfigFile::Syminfo";
 use constant Decode  => "DOCSIS::ConfigFile::Decode";
 use constant Encode  => "DOCSIS::ConfigFile::Encode";
 
-our $VERSION = eval '0.62';
+our $VERSION = eval '0.63';
 our $TRACE   = 0;
 
 =head1 ATTRIBUTES
@@ -296,21 +297,56 @@ returns a binary encoded string. See L</DESCRIPTION> and the unit tests for
 example input. For other structures, see the table generated by
 L<DOCSIS::ConfigFile::Syminfo/dump_symbol_tree>.
 
+When enconding MTA config files another arugment is accepted:
+
+    $binary_str = $self->encode([ { ... }, ... ], 'md5|sha1');
+
+As 'pktcMtaDevProvConfigHash' does not need to be included in the config at all
+times this param is optional. Only two variants are accpted - MD5, or SHA1
+The algorithm will then be used to define value for 'pktcMtaDevProvConfigHash'
+and this line will be added just above 'MtaConfigDelimiter' closing tag resulting in
+
+    MtaConfigDelimiter 1;
+    ...
+    SnmpMibObject enterprises.4491.2.2.1.1.2.7.0 HexString 0x1a2b3c4d5e6f... ;
+    MtaConfigDelimiter 255;
+
 =cut
 
 sub encode {
     my $self   = shift;
     my $config = shift || '__undefined_input__';
+    my $algo   = shift;
 
     if(ref $config ne 'ARRAY') {
         confess 'Usage: $self->encode( ArrayRef[HashRef] )';
     }
 
+    if ($algo and $algo !~ /^(?:md5|sha1)$/i) {
+        confess "Usage: $self->encode( ArrayRef[HashRef], 'md5|sha1' )";
+    }
+    $algo = lc $algo if $algo;
+
     $self->{'cmts_mic'}  = {};
     $self->{'binstring'} = $self->_encode_loop($config) || q();
 
     if(grep { $_->{'name'} eq 'MtaConfigDelimiter' } @$config) {
         $self->{'_MtaConfigDelimiter'} = 1; # for internal usage
+
+        if ($self->{binstring} and $algo)
+        {
+            my $hash = $algo eq 'md5'
+                        ? md5_hex  $self->{binstring}
+                        : sha1_hex $self->{binstring};
+
+            if ($hash)
+            {
+                splice @$config, $#{$config}, 0,
+                    { name => 'SnmpMibObject', value => { oid => '1.3.6.1.4.1.4491.2.2.1.1.2.7.0', type => 'STRING', value => "0x${hash}" }};
+
+                $self->{binstring} = $self->_encode_loop ($config) || q();
+            }
+        }
     }
     else {
         $self->{'_DefaultConfigDelimiter'} = 1; # for internal usage
